@@ -49,11 +49,11 @@ The core modules currently are:
 =back
 
 A better overview of the methods found in a Result class can be found
-in L<DBIx::Class::ResultClass>.
+in L<DBIx::Class::Manual::ResultClass>.
 
-=head1 AUTHORS
+=head1 AUTHOR AND CONTRIBUTORS
 
-See L<DBIx::Class/CONTRIBUTORS>
+See L<AUTHOR|DBIx::Class/AUTHOR> and L<CONTRIBUTORS|DBIx::Class/CONTRIBUTORS> in DBIx::Class
 
 =head1 LICENSE
 
