@@ -418,7 +418,7 @@ $rel_name.
 
 =item Arguments: none
 
-=item Return Value: L<$result|DBIx::Class::ResultClass> | L<$related_resultset|DBIx::Class::ResultSet> | undef
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass> | L<$related_resultset|DBIx::Class::ResultSet> | undef
 
 =back
 
@@ -431,7 +431,7 @@ $rel_name.
 This is the recommended way to transverse through relationships, based
 on the L</accessor> name given in the relationship definition.
 
-This will return either a L<Result|DBIx::Class::ResultClass> or a
+This will return either a L<Result|DBIx::Class::Manual::ResultClass> or a
 L<ResultSet|DBIx::Class::ResultSet>, depending on if the relationship is
 C<single> (returns only one row) or C<multi> (returns many rows).  The
 method may also return C<undef> if the relationship doesn't exist for
@@ -544,15 +544,13 @@ sub related_resultset {
 
 =item Arguments: $rel_name, $cond?, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
 
-=item Return Value: L<$resultset|DBIx::Class::ResultSet> (scalar context) | L<@result_objs|DBIx::Class::ResultClass> (list context)
+=item Return Value: L<$resultset|DBIx::Class::ResultSet> (scalar context) | L<@result_objs|DBIx::Class::Manual::ResultClass> (list context)
 
 =back
 
 Run a search on a related resultset. The search will be restricted to the
-item or items represented by the L<DBIx::Class::ResultSet> it was called
-upon. This method can be called on a L<ResultSource|DBIx::Class::ResultSource>,
-L<ResultSet|DBIx::Class::ResultSet>, or a L<Result|DBIx::Class::ResultClass>
-class.
+results represented by the L<DBIx::Class::ResultSet> it was called
+upon.
 
 See L<DBIx::Class::ResultSet/search_related> for more information.
 
@@ -583,10 +581,8 @@ sub search_related_rs {
 
 =back
 
-Returns the count of all the items in the related resultset, restricted by the
-current item or where conditions. This method can be called on a L<ResultSource|DBIx::Class::ResultSource>,
-L<ResultSet|DBIx::Class::ResultSet>, or a L<Result|DBIx::Class::ResultClass>
-class.
+Returns the count of all the rows in the related resultset, restricted by the
+current result or where conditions.
 
 =cut
 
@@ -599,21 +595,21 @@ sub count_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: $rel_name, \%col_data
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
-Create a new item of the related foreign class.  It will magically set
+Create a new result object of the related foreign class.  It will magically set
 any foreign key columns of the new object to the related primary key columns
-of the source object for you.  The newly created item will not be saved into
+of the source object for you.  The newly created result will not be saved into
 your storage until you call L<DBIx::Class::Row/insert> on it.
 
 =cut
 
 sub new_related {
-  my ($self, $rel, $values, $attrs) = @_;
+  my ($self, $rel, $values) = @_;
 
   # FIXME - this is a bad position for this (also an identical copy in
   # set_from_related), but I have no saner way to hook, and I absolutely
@@ -642,23 +638,24 @@ sub new_related {
     }
   }
 
-  my $row = $self->search_related($rel)->new($values, $attrs);
-  return $row;
+  return $self->search_related($rel)->new_result($values);
 }
 
 =head2 create_related
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: $rel_name, \%col_data
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
-Creates a new item, similarly to new_related, and also inserts the item's data
-into your storage medium. See the distinction between C<create> and C<new>
-in L<DBIx::Class::ResultSet> for details.
+  my $result = $obj->create_related($rel_name, \%col_data);
+
+Creates a new result object, similarly to new_related, and also inserts the
+result's data into your storage medium. See the distinction between C<create>
+and C<new> in L<DBIx::Class::ResultSet> for details.
 
 =cut
 
@@ -674,12 +671,14 @@ sub create_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data | @pk_values, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: $rel_name, \%col_data | @pk_values, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
-=item Return Value: L<$result|DBIx::Class::ResultClass> | undef
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass> | undef
 
 =back
 
+  my $result = $obj->find_related($rel_name, \%col_data);
+
 Attempt to find a related object using its primary key or unique constraints.
 See L<DBIx::Class::ResultSet/find> for details.
 
@@ -695,13 +694,13 @@ sub find_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
-Find an item of a related class.  See L<DBIx::Class::ResultSet/find_or_new>
+Find a result object of a related class.  See L<DBIx::Class::ResultSet/find_or_new>
 for details.
 
 =cut
@@ -716,13 +715,13 @@ sub find_or_new_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
-Find or create an item of a related class. See
+Find or create a result object of a related class. See
 L<DBIx::Class::ResultSet/find_or_create> for details.
 
 =cut
@@ -737,13 +736,13 @@ sub find_or_create_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, { key => $unique_constraint }?
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
-Update or create an item of a related class. See
+Update or create a result object of a related class. See
 L<DBIx::Class::ResultSet/update_or_create> for details.
 
 =cut
@@ -758,9 +757,9 @@ sub update_or_create_related {
 
 =over 4
 
-=item Arguments: $rel_name, L<$result|DBIx::Class::ResultClass>
+=item Arguments: $rel_name, L<$result|DBIx::Class::Manual::ResultClass>
 
-=item Return Value: 1
+=item Return Value: not defined
 
 =back
 
@@ -821,9 +820,9 @@ sub set_from_related {
 
 =over 4
 
-=item Arguments: $rel_name, L<$result|DBIx::Class::ResultClass>
+=item Arguments: $rel_name, L<$result|DBIx::Class::Manual::ResultClass>
 
-=item Return Value: 1
+=item Return Value: not defined
 
 =back
 
@@ -850,7 +849,7 @@ sub update_from_related {
 
 =back
 
-Delete any related item subject to the given conditions.  Internally, this
+Delete any related row, subject to the given conditions.  Internally, this
 calls:
 
   $self->search_related(@_)->delete
@@ -868,14 +867,32 @@ sub delete_related {
 
 =head2 add_to_$rel
 
-B<Currently only available for C<has_many>, C<many-to-many> and 'multi' type
+B<Currently only available for C<has_many>, C<many_to_many> and 'multi' type
 relationships.>
 
+=head3 has_many / multi
+
 =over 4
 
-=item Arguments: \%col_data, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
+=item Arguments: \%col_data
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
+
+=back
+
+Creates/inserts a new result object.  Internally, this calls:
+
+  $self->create_related($rel, @_)
+
+And returns the result of that.
+
+=head3 many_to_many
+
+=over 4
+
+=item Arguments: (\%col_data | L<$result|DBIx::Class::Manual::ResultClass>), \%link_col_data?
+
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -887,21 +904,23 @@ relationships.>
       # creates a new My::DBIC::Schema::Role result object and the linking table
       # object with an extra column in the link
 
-Adds a linking table object for C<$obj> or C<$foreign_vals>. If the first
-argument is a hash reference, the related object is created first with the
-column values in the hash. If an object reference is given, just the linking
-table object is created. In either case, any additional column values for the
-linking table object can be specified in C<$link_vals>.
+Adds a linking table object. If the first argument is a hash reference, the
+related object is created first with the column values in the hash. If an object
+reference is given, just the linking table object is created. In either case,
+any additional column values for the linking table object can be specified in
+C<\%link_col_data>.
+
+See L<DBIx::Class::Relationship/many_to_many> for additional details.
 
 =head2 set_$rel
 
-B<Currently only available for C<many-to-many> relationships.>
+B<Currently only available for C<many_to_many> relationships.>
 
 =over 4
 
-=item Arguments: (\@hashrefs_of_col_data | L<@result_objs|DBIx::Class::ResultClass>), $link_vals?
+=item Arguments: (\@hashrefs_of_col_data | L<@result_objs|DBIx::Class::Manual::ResultClass>), $link_vals?
 
-=item Return Value: undefined
+=item Return Value: not defined
 
 =back
 
@@ -931,13 +950,13 @@ removed in a future version.
 
 =head2 remove_from_$rel
 
-B<Currently only available for C<many-to-many> relationships.>
+B<Currently only available for C<many_to_many> relationships.>
 
 =over 4
 
-=item Arguments: L<$result|DBIx::Class::ResultClass>
+=item Arguments: L<$result|DBIx::Class::Manual::ResultClass>
 
-=item Return Value: undefined
+=item Return Value: not defined
 
 =back
 
@@ -949,9 +968,9 @@ Removes the link between the current object and the related object. Note that
 the related object itself won't be deleted unless you call ->delete() on
 it. This method just removes the link between the two objects.
 
-=head1 AUTHORS
+=head1 AUTHOR AND CONTRIBUTORS
 
-See L<DBIx::Class/CONTRIBUTORS>
+See L<AUTHOR|DBIx::Class/AUTHOR> and L<CONTRIBUTORS|DBIx::Class/CONTRIBUTORS> in DBIx::Class
 
 =head1 LICENSE
 
