@@ -41,21 +41,24 @@ as well as invocations of 'single' (
 L<belongs_to|DBIx::Class::Relationship/belongs_to>,
 L<has_one|DBIx::Class::Relationship/has_one> or
 L<might_have|DBIx::Class::Relationship/might_have>)
-relationship accessors of L<Result|DBIx::Class::ResultClass> objects.
+relationship accessors of L<Result|DBIx::Class::Manual::ResultClass> objects.
 
 =head1 NOTE
 
-All "Row objects" created from a Schema-attached L<DBIx::Class::ResultSet>
-object (such as a typical C<L<search|DBIx::Class::ResultSet/search>-E<gt>L<next|DBIx::Class::ResultSet/next>>
-call) are actually Result instances, based on your application's
-L<Result class|DBIx::Class::Manual::Glossary/Result class>.
+All "Row objects" derived from a Schema-attached L<DBIx::Class::ResultSet>
+object (such as a typical C<< L<search|DBIx::Class::ResultSet/search
+>->L<next|DBIx::Class::ResultSet/next> >> call) are actually Result
+instances, based on your application's
+L<Result class|DBIx::Class::Manual::Glossary/Result_class>.
 
-Since these Result classes should be inheriting from L<DBIx::Class::Core>,
-all of the parent methods there should be available to all
-L<Result objects|DBIx::Class::Manual::Glossary/Result>.  This module,
-L<DBIx::Class::Row>, is included in the Core set, but it does not detail
-all of the methods available to Result objects.  For a more comprehensive
-list of those methods, look at L<DBIx::Class::ResultClass/INHERITED METHODS>.
+L<DBIx::Class::Row> implements most of the row-based communication with the
+underlying storage, but a Result class B<should not inherit from it directly>.
+Usually, Result classes inherit from L<DBIx::Class::Core>, which in turn
+combines the methods from several classes, one of them being
+L<DBIx::Class::Row>.  Therefore, while many of the methods available to a
+L<DBIx::Class::Core>-derived Result class are described in the following
+documentation, it does not detail all of the methods available to Result
+objects.  Refer to L<DBIx::Class::Manual::ResultClass> for more info.
 
 =head1 METHODS
 
@@ -69,7 +72,7 @@ list of those methods, look at L<DBIx::Class::ResultClass/INHERITED METHODS>.
 
 =item Arguments: \%attrs or \%colsandvalues
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -295,10 +298,8 @@ sub new {
 
 =back
 
-This is the recommended way to get/set individual columns, as it will
-call L<get|DBIx::Class::InflateColumn/get_inflated_column>/L<set_inflated_column|DBIx::Class::InflateColumn/set_inflated_column>
-as necessary.  Only call the basic L<get|/get_column>/L<set_column|/set_column>
-methods if you absolutely need the raw value from storage.
+A column accessor method is created for each column, which is used for
+getting/setting the value for that column.
 
 The actual method name is based on the L<accessor|DBIx::Class::ResultSource/accessor>
 name given in the table definition.  Like L</set_column>, this will
@@ -312,7 +313,7 @@ not store the data until L</insert> or L</update> is called on the row.
 
 =item Arguments: none
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -493,7 +494,7 @@ sub in_storage {
 
 =item Arguments: none or a hashref
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -571,7 +572,7 @@ sub update {
 
 =item Arguments: none
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -760,7 +761,7 @@ sub get_dirty_columns {
 
 =item Arguments: $columnname
 
-=item Return Value: undefined
+=item Return Value: not defined
 
 =back
 
@@ -973,7 +974,7 @@ sub _track_storage_value {
 
 =item Arguments: \%columndata
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -999,7 +1000,7 @@ sub set_columns {
 
 =item Arguments: \%columndata
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -1056,7 +1057,7 @@ sub set_inflated_columns {
 
 =item Arguments: \%replacementdata
 
-=item Return Value: L<$result|DBIx::Class::ResultClass> copy
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass> copy
 
 =back
 
@@ -1157,7 +1158,7 @@ sub store_column {
 
 =item Arguments: L<$result_source|DBIx::Class::ResultSource>, \%columndata, \%prefetcheddata
 
-=item Return Value: L<$result|DBIx::Class::ResultClass>
+=item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
 =back
 
@@ -1372,7 +1373,7 @@ sub result_source {
 
 =item Arguments: $columnname, \%columninfo
 
-=item Return Value: undefined
+=item Return Value: not defined
 
 =back
 
@@ -1439,7 +1440,7 @@ sub get_from_storage {
     return $resultset->find($self->_storage_ident_condition);
 }
 
-=head2 discard_changes ($attrs?)
+=head2 discard_changes
 
   $row->discard_changes
 
@@ -1513,9 +1514,24 @@ sub throw_exception {
   }
 }
 
-=head1 AUTHORS
+=head2 id
 
-See L<DBIx::Class/CONTRIBUTORS>
+  my @pk = $row->id;
+
+=over
+
+=item Arguments: none
+
+=item Returns: A list of primary key values
+
+=back
+
+Returns the primary key(s) for a row. Can't be called as a class method.
+Actually implemented in L<DBIx::Class::PK>
+
+=head1 AUTHOR AND CONTRIBUTORS
+
+See L<AUTHOR|DBIx::Class/AUTHOR> and L<CONTRIBUTORS|DBIx::Class/CONTRIBUTORS> in DBIx::Class
 
 =head1 LICENSE
 
