@@ -72,9 +72,9 @@ method.
 
 The deserializing hook called on the object during deserialization.
 
-=head1 AUTHORS
+=head1 AUTHOR AND CONTRIBUTORS
 
-See L<DBIx::Class/CONTRIBUTORS>
+See L<AUTHOR|DBIx::Class/AUTHOR> and L<CONTRIBUTORS|DBIx::Class/CONTRIBUTORS> in DBIx::Class
 
 =head1 LICENSE
 
